<?php

namespace App\Filament\Resources;

use App\Filament\Resources\ServicePlanResource\Pages;
use App\Filament\Resources\ServicePlanResource\RelationManagers;
use App\Models\ServicePlan;
use App\Models\Service;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Filament\Forms\Components\Section;
use Filament\Forms\Components\Repeater;
class ServicePlanResource extends Resource
{
    protected static ?string $model = ServicePlan::class;
    protected static ?string $navigationGroup = 'Services';
    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?int $navigationSort = 2;
    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Section::make('Service Plans')
                ->description('Please enter plan services')
                ->schema([
                    Forms\Components\TextInput::make('plan')
                    ->maxLength(191)
                    ->columnSpanFull(),
                Forms\Components\TextInput::make('planTitleOne')
                    ->maxLength(191),
                Forms\Components\TextInput::make('planTitleTwo')
                    ->maxLength(191),
                Forms\Components\Textarea::make('planSubtitle')
                    ->maxLength(191)
                    ->columnSpanFull(),
                Repeater::make('planFeatures')
                    ->schema([
                        Forms\Components\TextInput::make('featName')->required(),
                        Forms\Components\Select::make('status')
                            ->options([
                                '1' => 'Active',
                                '0' => 'Closed',
                            ])->columns(2),
                    ]) ->columnSpanFull(),
                Forms\Components\Select::make('service_id')
                    ->label('Select Service')
                    ->options(Service::all()->pluck('name', 'id'))
                    ->columnSpanFull()
                    ->searchable()
            ])->columns(2),

            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('plan')
                    ->searchable(),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ]);
    }

    public static function getRelations(): array
    {
        return [
            //
        ];
    }

    public static function getPages(): array
    {
        return [
            'index' => Pages\ListServicePlans::route('/'),
            'create' => Pages\CreateServicePlan::route('/create'),
            'edit' => Pages\EditServicePlan::route('/{record}/edit'),
        ];
    }
}
