<?php

namespace App\Filament\Resources;

use App\Filament\Resources\ServiceResource\Pages;
use App\Filament\Resources\ServiceResource\RelationManagers;
use App\Models\Service;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Filament\Forms\Components\Section;

class ServiceResource extends Resource
{
    protected static ?string $model = Service::class;
    protected static ?string $navigationGroup = 'Services';
    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?int $navigationSort = 1;
    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Section::make('Service Information')
                    ->description('Please add service name and title')
                    ->schema([
                        Forms\Components\TextInput::make('name')

                        ->columnSpanFull()
                        ->maxLength(191),
                    Forms\Components\TextInput::make('titleOne')

                        ->maxLength(191),
                    Forms\Components\TextInput::make('titleTwo')

                        ->maxLength(191),
                    Forms\Components\RichEditor::make('desc')

                        ->label('Description')
                        ->columnSpanFull()
                        ->maxLength(191),
                    Forms\Components\FileUpload::make('featImg')
                        ->image()
                        ->label('Featured Image')
                        ->directory("featImg")
                        ->columnSpanFull()
                ])->columns(2),

                Section::make('Gallery Information')
                    ->description('Please add optimised images')
                    ->schema([
                    Forms\Components\TextInput::make('galleryTitleOne')

                        ->maxLength(191),
                    Forms\Components\TextInput::make('galleryTitleTwo')

                        ->maxLength(191),
                    Forms\Components\TextInput::make('gallerySubtitle')

                        ->columnSpanFull()

                        ->maxLength(191),
                    Forms\Components\FileUpload::make('galleryImages')
                        ->image()
                        ->multiple()
    
                        ->directory("galleryImages")
                        ->columnSpanFull()
                ])->columns(2),

            Section::make('Video Information')
                ->description('Please add optimised videos for faster page loads')
                ->schema([
                    Forms\Components\TextInput::make('videoTitle')
        
                    ->maxLength(191),
                Forms\Components\TextInput::make('videoSubtitle')
          
                    ->maxLength(191),
                Forms\Components\FileUpload::make('videoUrl')
     
                    ->directory("videoUrl")
                    ->columnSpanFull()
                    ->label('Video')
            ])->columns(2),

            
            Section::make('Product Information')
            ->description('Please add plan disclaimer and product section title and subtitles')
            ->schema([
                Forms\Components\RichEditor::make('allPlanInfo')

                    ->label('Plans & Product Disclaimer')
                    ->columnSpanFull()
                    ->maxLength(191),
                Forms\Components\TextInput::make('productTitle')
      
                    ->maxLength(191),
                Forms\Components\TextInput::make('productSubtitle')
     
                
                    ->maxLength(191),
            ])->columns(2),
        ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('name')
                    ->searchable(),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ]);
    }

    public static function getRelations(): array
    {
        return [
            //
        ];
    }

    public static function getPages(): array
    {
        return [
            'index' => Pages\ListServices::route('/'),
            'create' => Pages\CreateService::route('/create'),
            'edit' => Pages\EditService::route('/{record}/edit'),
        ];
    }
}
